summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/map/unit.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/map/unit.c b/src/map/unit.c
index 371a75ac7..7b270adc7 100644
--- a/src/map/unit.c
+++ b/src/map/unit.c
@@ -327,7 +327,8 @@ int unit_walktoxy( struct block_list *bl, short x, short y, int flag)
path_search(&wpd, bl->m, bl->x, bl->y, x, y, flag&1, CELL_CHKNOPASS); // Count walk path cells
#ifdef OFFICIAL_WALKPATH
if( !path_search_long(NULL, bl->m, bl->x, bl->y, x, y, CELL_CHKNOPASS) // Check if there is an obstacle between
- && wpd.path_len > 14 ) // Official number of walkable cells is 14 if and only if there is an obstacle between. [malufett]
+ && (wpd.path_len > 14) // Official number of walkable cells is 14 if and only if there is an obstacle between. [malufett]
+ && (bl->type != BL_NPC) ) // If type is a NPC, please disregard.
return 0;
#endif
if( (battle_config.max_walk_path < wpd.path_len) && (bl->type != BL_NPC) )